#!/bin/bash

RED='\033[0;31m'
NC='\033[0m'
pwd=$(pwd)
tmp=($RANDOM)

echo -e "${RED}Mount the installer image${NC}\n"
hdiutil attach /Applications/Install\ OS\ X\ Yosemite.app/Contents/SharedSupport/InstallESD.dmg -noverify -nobrowse -mountpoint /Volumes/install_app

echo -e "${RED}Convert the boot image to a sparse bundle${NC}\n"
hdiutil convert /Volumes/install_app/BaseSystem.dmg -format UDSP -o /tmp/Yosemite

echo -e "${RED}Increase the sparse bundle capacity to accommodate the packages${NC}\n"
hdiutil resize -size 8g /tmp/Yosemite.sparseimage

echo -e "${RED}Mount the sparse bundle for package addition${NC}\n"
hdiutil attach /tmp/Yosemite.sparseimage -noverify -nobrowse -mountpoint /Volumes/install_build

echo -e "${RED}Remove Package link and replace with actual files${NC}\n"
rm /Volumes/install_build/System/Installation/Packages
cp -rp /Volumes/install_app/Packages /Volumes/install_build/System/Installation/

echo -e "${RED}Extract Kernel from Package (this takes some time, grab a coffee)${NC}\n"
mkdir /tmp/iso.$tmp
cp /Volumes/install_build/System/Installation/Packages/Essentials.pkg /tmp/iso.$tmp
cd /tmp/iso.$tmp
cp /$pwd/pbzx /tmp/iso.$tmp
./pbzx Essentials.pkg | cpio -idmu
mkdir /Volumes/install_build/System/Library/Kernels
cp System/Library/Kernels/kernel /Volumes/install_build/System/Library/Kernels/
rm -rf /tmp/iso.$tmp

echo -e "${RED}Copy Yosemite installer dependencies${NC}\n"
cp -rp /Volumes/install_app/BaseSystem.chunklist /Volumes/install_build/BaseSystem.chunklist
cp -rp /Volumes/install_app/BaseSystem.dmg /Volumes/install_build/BaseSystem.dmg

echo -e "${RED}Unmount the installer image${NC}\n"
hdiutil detach /Volumes/install_app

echo -e "${RED}Unmount the sparse bundle${NC}\n"
hdiutil detach /Volumes/install_build

echo -e "${RED}Resize the partition in the sparse bundle to remove any free space ${NC}\n"
hdiutil resize -size `hdiutil resize -limits /tmp/Yosemite.sparseimage | tail -n 1 | awk '{ print $1 }'`b /tmp/Yosemite.sparseimage

echo -e "${RED}Convert the sparse bundle to ISO/CD master${NC}\n"
hdiutil convert /tmp/Yosemite.sparseimage -format UDTO -o /tmp/Yosemite

echo -e "${RED}Remove the sparse bundle${NC}\n"
rm /tmp/Yosemite.sparseimage

echo -e "${RED}Rename the ISO and move it to the desktop${NC}\n"
mv /tmp/Yosemite.cdr ~/Desktop/Yosemite.iso